
#line 3 "keyval_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer pmix_util_keyval_yy_create_buffer
#define yy_delete_buffer pmix_util_keyval_yy_delete_buffer
#define yy_flex_debug pmix_util_keyval_yy_flex_debug
#define yy_init_buffer pmix_util_keyval_yy_init_buffer
#define yy_flush_buffer pmix_util_keyval_yy_flush_buffer
#define yy_load_buffer_state pmix_util_keyval_yy_load_buffer_state
#define yy_switch_to_buffer pmix_util_keyval_yy_switch_to_buffer
#define yyin pmix_util_keyval_yyin
#define yyleng pmix_util_keyval_yyleng
#define yylex pmix_util_keyval_yylex
#define yylineno pmix_util_keyval_yylineno
#define yyout pmix_util_keyval_yyout
#define yyrestart pmix_util_keyval_yyrestart
#define yytext pmix_util_keyval_yytext
#define yywrap pmix_util_keyval_yywrap
#define yyalloc pmix_util_keyval_yyalloc
#define yyrealloc pmix_util_keyval_yyrealloc
#define yyfree pmix_util_keyval_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE pmix_util_keyval_yyrestart(pmix_util_keyval_yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t pmix_util_keyval_yyleng;

extern FILE *pmix_util_keyval_yyin, *pmix_util_keyval_yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE pmix_util_keyval_yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-pmix_util_keyval_yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < pmix_util_keyval_yyleng; ++yyl )\
                    if ( pmix_util_keyval_yytext[yyl] == '\n' )\
                        --pmix_util_keyval_yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pmix_util_keyval_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up pmix_util_keyval_yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via pmix_util_keyval_yyrestart()), so that the user can continue scanning by
	 * just pointing pmix_util_keyval_yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when pmix_util_keyval_yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t pmix_util_keyval_yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow pmix_util_keyval_yywrap()'s to do buffer switches
 * instead of setting up a fresh pmix_util_keyval_yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void pmix_util_keyval_yyrestart (FILE *input_file  );
void pmix_util_keyval_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE pmix_util_keyval_yy_create_buffer (FILE *file,int size  );
void pmix_util_keyval_yy_delete_buffer (YY_BUFFER_STATE b  );
void pmix_util_keyval_yy_flush_buffer (YY_BUFFER_STATE b  );
void pmix_util_keyval_yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void pmix_util_keyval_yypop_buffer_state (void );

static void pmix_util_keyval_yyensure_buffer_stack (void );
static void pmix_util_keyval_yy_load_buffer_state (void );
static void pmix_util_keyval_yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER pmix_util_keyval_yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE pmix_util_keyval_yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE pmix_util_keyval_yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE pmix_util_keyval_yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *pmix_util_keyval_yyalloc (yy_size_t  );
void *pmix_util_keyval_yyrealloc (void *,yy_size_t  );
void pmix_util_keyval_yyfree (void *  );

#define yy_new_buffer pmix_util_keyval_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        pmix_util_keyval_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pmix_util_keyval_yy_create_buffer(pmix_util_keyval_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        pmix_util_keyval_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pmix_util_keyval_yy_create_buffer(pmix_util_keyval_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *pmix_util_keyval_yyin = (FILE *) 0, *pmix_util_keyval_yyout = (FILE *) 0;

typedef int yy_state_type;

extern int pmix_util_keyval_yylineno;

int pmix_util_keyval_yylineno = 1;

extern char *pmix_util_keyval_yytext;
#define yytext_ptr pmix_util_keyval_yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up pmix_util_keyval_yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	pmix_util_keyval_yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 22
#define YY_END_OF_BUFFER 23
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[93] =
    {   0,
        5,    5,   23,   21,   22,   10,   21,   22,    1,   22,
       21,   22,   11,   21,   22,   11,   21,   22,   21,   22,
        9,   21,   22, 8205,   22,16397,   22,   12,   22, 8205,
       22,16397,    5,   22,    7,   22,    6,   22,   14,   22,
       22,   17,   22,   14,   22,   14,   22,   14,   22,   10,
        1,    9,    2,   11,   11,   11,   11,    4,    9, 8205,
    16397, 8205,   12, 8205,16397, 8205,    5,    6,    6,    8,
       14,   17,   14,   14,   14,   14,   14,   11,    3,   16,
       14,   16,   15,   14,   15,   11,   20,   20,   20,   19,
       19,   18

    } ;

static yyconst flex_int16_t yy_accept[85] =
    {   0,
        1,    1,    1,    1,    1,    2,    3,    3,    3,    4,
        6,    9,   11,   13,   16,   19,   21,   24,   27,   28,
       30,   33,   35,   37,   39,   41,   42,   44,   46,   48,
       50,   51,   52,   53,   53,   54,   55,   56,   57,   58,
       59,   59,   60,   62,   63,   63,   64,   66,   67,   68,
       69,   70,   71,   72,   72,   73,   74,   75,   75,   76,
       77,   77,   78,   79,   79,   79,   80,   80,   81,   83,
       83,   84,   86,   87,   87,   87,   88,   89,   90,   91,
       91,   92,   93,   93
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    7,    1,
        1,    8,    1,    1,    9,   10,   11,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,    1,    1,    1,
       12,    1,    1,    1,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
        1,    1,    1,    1,   10,    1,   13,   10,   14,   10,

       10,   10,   10,   10,   10,   10,   10,   10,   15,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   16,
       10,   10,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[17] =
    {   0,
        1,    2,    3,    4,    1,    1,    1,    5,    6,    6,
        1,    1,    6,    6,    6,    6
    } ;

static yyconst flex_int16_t yy_base[100] =
    {   0,
        0,    0,   15,   18,   20,   21,   28,   34,  143,  252,
       40,  252,  121,   44,   52,   37,   23,  115,   67,  252,
       70,    0,  252,   38,    0,  111,  252,   73,   45,   49,
        0,  252,   60,  105,  252,   50,    0,   93,   76,  252,
       98,   77,   98,   91,   80,  252,   83,   86,    0,   83,
       84,  252,    0,   60,  252,   94,   97,   50,  101,  102,
       33,  108,   21,  109,   23,  252,  114,    0,    0,  118,
        0,    0,  119,  125,  140,  252,  136,    0,  151,  152,
      155,  156,  252,  160,  166,  172,  178,  184,  190,  196,
      202,  207,  211,  217,  223,  229,  235,  240,  245

    } ;

static yyconst flex_int16_t yy_def[100] =
    {   0,
       83,    1,   84,   84,   85,   85,   86,   86,   83,   83,
       83,   83,   87,   83,   14,   83,   83,   88,   88,   83,
       88,   89,   83,   90,   91,   92,   83,   91,   93,   94,
       11,   83,   83,   87,   83,   15,   15,   15,   15,   83,
       95,   83,   88,   88,   88,   83,   88,   88,   89,   90,
       90,   83,   91,   92,   83,   91,   93,   96,   93,   94,
       97,   94,   15,   98,   95,   83,   96,   67,   59,   97,
       70,   62,   15,   83,   99,   83,   74,   74,   83,   99,
       83,   83,    0,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83

    } ;

static yyconst flex_int16_t yy_nxt[269] =
    {   0,
       10,   11,   12,   11,   10,   13,   10,   10,   14,   15,
       16,   17,   15,   15,   15,   15,   19,   20,   21,   19,
       20,   21,   23,   23,   42,   66,   42,   24,   24,   26,
       27,   28,   29,   73,   30,   26,   27,   28,   29,   70,
       30,   31,   32,   31,   40,   51,   58,   41,   52,   59,
       61,   33,   36,   37,   67,   62,   37,   37,   38,   39,
       37,   42,   55,   42,   38,   39,   37,   37,   45,   46,
       47,   48,   46,   47,   54,   55,   56,   64,   42,   64,
       42,   45,   46,   47,   48,   46,   47,   48,   46,   47,
       83,   51,   44,   83,   52,   54,   55,   56,   58,   44,

       66,   59,   68,   61,   69,   59,   63,   35,   62,   71,
       64,   72,   64,   55,   62,   68,   44,   68,   67,   71,
       75,   71,   75,   35,   70,   76,   77,   76,   77,   76,
       76,   76,   76,   78,   78,   76,   79,   78,   78,   78,
       78,   75,   83,   75,   76,   76,   83,   83,   76,   76,
       76,   76,   81,   82,   81,   82,   81,   82,   81,   82,
       18,   18,   18,   18,   18,   18,   22,   22,   22,   22,
       22,   22,   25,   25,   25,   25,   25,   25,   34,   34,
       34,   34,   34,   34,   43,   43,   83,   43,   43,   43,
       49,   49,   83,   49,   83,   49,   50,   50,   83,   50,

       50,   50,   53,   83,   83,   53,   53,   53,   54,   54,
       54,   57,   57,   83,   57,   57,   57,   60,   60,   83,
       60,   60,   60,   65,   65,   65,   65,   65,   65,   58,
       58,   83,   58,   58,   58,   61,   61,   83,   61,   61,
       61,   74,   83,   74,   83,   74,   80,   83,   80,   83,
       80,    9,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83
    } ;

static yyconst flex_int16_t yy_chk[269] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,    3,    3,    4,
        4,    4,    5,    6,   17,   65,   17,    5,    6,    7,
        7,    7,    7,   63,    7,    8,    8,    8,    8,   61,
        8,   11,   11,   11,   16,   24,   29,   16,   24,   29,
       30,   11,   14,   14,   58,   30,   14,   14,   14,   14,
       15,   33,   54,   33,   36,   36,   15,   15,   19,   19,
       19,   21,   21,   21,   28,   28,   28,   39,   42,   39,
       42,   45,   45,   45,   47,   47,   47,   48,   48,   48,
       50,   51,   44,   50,   51,   56,   56,   56,   57,   43,

       41,   57,   59,   60,   59,   59,   38,   34,   60,   62,
       64,   62,   64,   26,   62,   67,   18,   67,   67,   70,
       73,   70,   73,   13,   70,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       74,   75,    9,   75,   77,   77,    0,    0,   77,   77,
       77,   77,   79,   80,   79,   80,   81,   82,   81,   82,
       84,   84,   84,   84,   84,   84,   85,   85,   85,   85,
       85,   85,   86,   86,   86,   86,   86,   86,   87,   87,
       87,   87,   87,   87,   88,   88,    0,   88,   88,   88,
       89,   89,    0,   89,    0,   89,   90,   90,    0,   90,

       90,   90,   91,    0,    0,   91,   91,   91,   92,   92,
       92,   93,   93,    0,   93,   93,   93,   94,   94,    0,
       94,   94,   94,   95,   95,   95,   95,   95,   95,   96,
       96,    0,   96,   96,   96,   97,   97,    0,   97,   97,
       97,   98,    0,   98,    0,   98,   99,    0,   99,    0,
       99,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[23] =
    {   0,
1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 
    1, 0, 0,     };

extern int pmix_util_keyval_yy_flex_debug;
int pmix_util_keyval_yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up pmix_util_keyval_yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *pmix_util_keyval_yytext;
#line 1 "keyval_lex.l"
#define YY_NO_INPUT 1
#line 6 "keyval_lex.l"
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2006 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2012      Los Alamos National Security, LLC. All rights
 *                         reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 */

#include <src/include/pmix_config.h>

#include <stdio.h>
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include "src/util/keyval/keyval_lex.h"

/*
 * local functions
 */

BEGIN_C_DECLS

int pmix_util_keyval_yywrap(void);

END_C_DECLS

/*
 * global variables
 */
int pmix_util_keyval_yynewlines = 1;
bool pmix_util_keyval_parse_done = false;
char *pmix_util_keyval_string = NULL;




#line 651 "keyval_lex.c"

#define INITIAL 0
#define VALUE 1
#define comment 2
#define MCA_VALUE 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int pmix_util_keyval_yylex_destroy (void );

int pmix_util_keyval_yyget_debug (void );

void pmix_util_keyval_yyset_debug (int debug_flag  );

YY_EXTRA_TYPE pmix_util_keyval_yyget_extra (void );

void pmix_util_keyval_yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *pmix_util_keyval_yyget_in (void );

void pmix_util_keyval_yyset_in  (FILE * in_str  );

FILE *pmix_util_keyval_yyget_out (void );

void pmix_util_keyval_yyset_out  (FILE * out_str  );

yy_size_t pmix_util_keyval_yyget_leng (void );

char *pmix_util_keyval_yyget_text (void );

int pmix_util_keyval_yyget_lineno (void );

void pmix_util_keyval_yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int pmix_util_keyval_yywrap (void );
#else
extern int pmix_util_keyval_yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( pmix_util_keyval_yytext, pmix_util_keyval_yyleng, 1, pmix_util_keyval_yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( pmix_util_keyval_yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( pmix_util_keyval_yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, pmix_util_keyval_yyin))==0 && ferror(pmix_util_keyval_yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(pmix_util_keyval_yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int pmix_util_keyval_yylex (void);

#define YY_DECL int pmix_util_keyval_yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after pmix_util_keyval_yytext and pmix_util_keyval_yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 61 "keyval_lex.l"


#line 837 "keyval_lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)pmix_util_keyval_yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! pmix_util_keyval_yyin )
			pmix_util_keyval_yyin = stdin;

		if ( ! pmix_util_keyval_yyout )
			pmix_util_keyval_yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			pmix_util_keyval_yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				pmix_util_keyval_yy_create_buffer(pmix_util_keyval_yyin,YY_BUF_SIZE );
		}

		pmix_util_keyval_yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of pmix_util_keyval_yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 84 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 252 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < pmix_util_keyval_yyleng; ++yyl )
				if ( pmix_util_keyval_yytext[yyl] == '\n' )
					   
    pmix_util_keyval_yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 63 "keyval_lex.l"
{ pmix_util_keyval_yynewlines++; return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 64 "keyval_lex.l"
{ pmix_util_keyval_yynewlines++; return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 65 "keyval_lex.l"
{ pmix_util_keyval_yynewlines++; return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 67 "keyval_lex.l"
{ BEGIN(comment);
                      return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 69 "keyval_lex.l"
; /* Eat up non '*'s */
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 70 "keyval_lex.l"
; /* Eat '*'s not followed by a '/' */
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 71 "keyval_lex.l"
{ pmix_util_keyval_yynewlines++;
                      return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 73 "keyval_lex.l"
{ BEGIN(INITIAL); /* Done with Block Comment */
                      return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 76 "keyval_lex.l"
{ BEGIN(VALUE); return PMIX_UTIL_KEYVAL_PARSE_EQUAL; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 77 "keyval_lex.l"
; /* whitespace */
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 78 "keyval_lex.l"
{ return PMIX_UTIL_KEYVAL_PARSE_SINGLE_WORD; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 80 "keyval_lex.l"
{ BEGIN(INITIAL); return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 81 "keyval_lex.l"
{ return PMIX_UTIL_KEYVAL_PARSE_VALUE; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 83 "keyval_lex.l"
{ BEGIN(INITIAL); return PMIX_UTIL_KEYVAL_PARSE_VALUE; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 84 "keyval_lex.l"
{ BEGIN(INITIAL); return PMIX_UTIL_KEYVAL_PARSE_VALUE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 85 "keyval_lex.l"
{ BEGIN(INITIAL); return PMIX_UTIL_KEYVAL_PARSE_VALUE; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 86 "keyval_lex.l"
{ BEGIN(INITIAL); BEGIN(INITIAL); return PMIX_UTIL_KEYVAL_PARSE_NEWLINE; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 88 "keyval_lex.l"
{BEGIN(MCA_VALUE); return PMIX_UTIL_KEYVAL_PARSE_MCAVAR; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 89 "keyval_lex.l"
{BEGIN(MCA_VALUE); return PMIX_UTIL_KEYVAL_PARSE_ENVEQL; }
	YY_BREAK
case 20:
/* rule 20 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pmix_util_keyval_yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up pmix_util_keyval_yytext again */
YY_RULE_SETUP
#line 90 "keyval_lex.l"
{ return PMIX_UTIL_KEYVAL_PARSE_ENVVAR; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 92 "keyval_lex.l"
{ return PMIX_UTIL_KEYVAL_PARSE_ERROR; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 94 "keyval_lex.l"
ECHO;
	YY_BREAK
#line 1082 "keyval_lex.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(VALUE):
			case YY_STATE_EOF(comment):
			case YY_STATE_EOF(MCA_VALUE):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed pmix_util_keyval_yyin at a new source and called
			 * pmix_util_keyval_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = pmix_util_keyval_yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( pmix_util_keyval_yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * pmix_util_keyval_yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of pmix_util_keyval_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			pmix_util_keyval_yyrestart(pmix_util_keyval_yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) pmix_util_keyval_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 84 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 84 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 83);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					pmix_util_keyval_yyrestart(pmix_util_keyval_yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( pmix_util_keyval_yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve pmix_util_keyval_yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    pmix_util_keyval_yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void pmix_util_keyval_yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        pmix_util_keyval_yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            pmix_util_keyval_yy_create_buffer(pmix_util_keyval_yyin,YY_BUF_SIZE );
	}

	pmix_util_keyval_yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	pmix_util_keyval_yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void pmix_util_keyval_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		pmix_util_keyval_yypop_buffer_state();
	 *		pmix_util_keyval_yypush_buffer_state(new_buffer);
     */
	pmix_util_keyval_yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	pmix_util_keyval_yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (pmix_util_keyval_yywrap()) processing, but the only time this flag
	 * is looked at is after pmix_util_keyval_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void pmix_util_keyval_yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	pmix_util_keyval_yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE pmix_util_keyval_yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) pmix_util_keyval_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) pmix_util_keyval_yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	pmix_util_keyval_yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with pmix_util_keyval_yy_create_buffer()
 * 
 */
    void pmix_util_keyval_yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		pmix_util_keyval_yyfree((void *) b->yy_ch_buf  );

	pmix_util_keyval_yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a pmix_util_keyval_yyrestart() or at EOF.
 */
    static void pmix_util_keyval_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	pmix_util_keyval_yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then pmix_util_keyval_yy_init_buffer was _probably_
     * called from pmix_util_keyval_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void pmix_util_keyval_yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		pmix_util_keyval_yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void pmix_util_keyval_yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	pmix_util_keyval_yyensure_buffer_stack();

	/* This block is copied from pmix_util_keyval_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from pmix_util_keyval_yy_switch_to_buffer. */
	pmix_util_keyval_yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void pmix_util_keyval_yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	pmix_util_keyval_yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		pmix_util_keyval_yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void pmix_util_keyval_yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)pmix_util_keyval_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)pmix_util_keyval_yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE pmix_util_keyval_yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) pmix_util_keyval_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	pmix_util_keyval_yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to pmix_util_keyval_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       pmix_util_keyval_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE pmix_util_keyval_yy_scan_string (yyconst char * yystr )
{
    
	return pmix_util_keyval_yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to pmix_util_keyval_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE pmix_util_keyval_yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) pmix_util_keyval_yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in pmix_util_keyval_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = pmix_util_keyval_yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in pmix_util_keyval_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pmix_util_keyval_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		pmix_util_keyval_yytext[pmix_util_keyval_yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = pmix_util_keyval_yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		pmix_util_keyval_yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int pmix_util_keyval_yyget_lineno  (void)
{
        
    return pmix_util_keyval_yylineno;
}

/** Get the input stream.
 * 
 */
FILE *pmix_util_keyval_yyget_in  (void)
{
        return pmix_util_keyval_yyin;
}

/** Get the output stream.
 * 
 */
FILE *pmix_util_keyval_yyget_out  (void)
{
        return pmix_util_keyval_yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t pmix_util_keyval_yyget_leng  (void)
{
        return pmix_util_keyval_yyleng;
}

/** Get the current token.
 * 
 */

char *pmix_util_keyval_yyget_text  (void)
{
        return pmix_util_keyval_yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void pmix_util_keyval_yyset_lineno (int  line_number )
{
    
    pmix_util_keyval_yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see pmix_util_keyval_yy_switch_to_buffer
 */
void pmix_util_keyval_yyset_in (FILE *  in_str )
{
        pmix_util_keyval_yyin = in_str ;
}

void pmix_util_keyval_yyset_out (FILE *  out_str )
{
        pmix_util_keyval_yyout = out_str ;
}

int pmix_util_keyval_yyget_debug  (void)
{
        return pmix_util_keyval_yy_flex_debug;
}

void pmix_util_keyval_yyset_debug (int  bdebug )
{
        pmix_util_keyval_yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from pmix_util_keyval_yylex_destroy(), so don't allocate here.
     */

    /* We do not touch pmix_util_keyval_yylineno unless the option is enabled. */
    pmix_util_keyval_yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    pmix_util_keyval_yyin = stdin;
    pmix_util_keyval_yyout = stdout;
#else
    pmix_util_keyval_yyin = (FILE *) 0;
    pmix_util_keyval_yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * pmix_util_keyval_yylex_init()
     */
    return 0;
}

/* pmix_util_keyval_yylex_destroy is for both reentrant and non-reentrant scanners. */
int pmix_util_keyval_yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		pmix_util_keyval_yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		pmix_util_keyval_yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	pmix_util_keyval_yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    pmix_util_keyval_yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * pmix_util_keyval_yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *pmix_util_keyval_yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *pmix_util_keyval_yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void pmix_util_keyval_yyfree (void * ptr )
{
	free( (char *) ptr );	/* see pmix_util_keyval_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 94 "keyval_lex.l"



/* Old flex (2.5.4a? and older) does not define a destroy function */
#if !defined(YY_FLEX_SUBMINOR_VERSION)
#define YY_FLEX_SUBMINOR_VERSION 0
#endif

#if (YY_FLEX_MAJOR_VERSION < 2) || (YY_FLEX_MAJOR_VERSION == 2 && (YY_FLEX_MINOR_VERSION < 5 || (YY_FLEX_MINOR_VERSION == 5 && YY_FLEX_SUBMINOR_VERSION < 5)))
int pmix_util_keyval_yylex_destroy(void)
{
    if (NULL != YY_CURRENT_BUFFER) {
        pmix_util_keyval_yy_delete_buffer(YY_CURRENT_BUFFER);
#if defined(YY_CURRENT_BUFFER_LVALUE)
        YY_CURRENT_BUFFER_LVALUE = NULL;
#else
        YY_CURRENT_BUFFER = NULL;
#endif  /* YY_CURRENT_BUFFER_LVALUE */
    }
    return YY_NULL;
}
#endif

int pmix_util_keyval_yywrap(void)
{
    pmix_util_keyval_parse_done = true;
    return 1;
}

/*
 * Ensure that we have a valid yybuffer to use.  Specifically, if this
 * scanner is invoked a second time, finish_parsing() (above) will
 * have been executed, and the current buffer will have been freed.
 * Flex doesn't recognize this fact because as far as it's concerned,
 * its internal state was already initialized, so it thinks it should
 * have a valid buffer.  Hence, here we ensure to give it a valid
 * buffer.
 */
int pmix_util_keyval_init_buffer(FILE *file)
{
    YY_BUFFER_STATE buf = pmix_util_keyval_yy_create_buffer(file,YY_BUF_SIZE);
    pmix_util_keyval_yy_switch_to_buffer(buf);

    return 0;
}

